The tag "Cc: sta...@dpdk.org" must be set when the commit must be
backported to a stable branch.

It must be located just below the "Fixes:" tag (without blank line)
and followed by a blank line, separated from SoB and review tags below.

Signed-off-by: Thomas Monjalon <thomas.monja...@6wind.com>
---
 devtools/check-git-log.sh | 16 +++++++++++-----
 1 file changed, 11 insertions(+), 5 deletions(-)

diff --git a/devtools/check-git-log.sh b/devtools/check-git-log.sh
index f6a35d2..9f1b435 100755
--- a/devtools/check-git-log.sh
+++ b/devtools/check-git-log.sh
@@ -170,9 +170,9 @@ bad=$(echo "$tags" |
        sed 's,^.,\t&,')
 [ -z "$bad" ] || printf "Wrong tag:\n$bad\n"
 
 # check blank line after last Fixes: tag
 bad=$(echo "$bodylines" |
-       sed -n 'N;/\nFixes:/D;/\n$/D;/^Fixes:/P' |
+       sed -n 'N;/\nFixes:/D;/\nC[Cc]: stable@/D;/\n$/D;/^Fixes:/P' |
        sed 's,^.,\t&,')
 [ -z "$bad" ] || printf "Missing blank line after 'Fixes' tag:\n$bad\n"
 
@@ -198,9 +198,15 @@ bad=$(for fixtag in $fixtags ; do
 done | sed 's,^,\t,')
 [ -z "$bad" ] || printf "Wrong 'Fixes' reference:\n$bad\n"
 
-# check CC:stable for fixes
+# check Cc: sta...@dpdk.org for fixes
 bad=$(for fix in $stablefixes ; do
-       git log --format='%b' -1 $fix | grep -qi '^CC: *sta...@dpdk.org' ||
+       git log --format='%b' -1 $fix | grep -qi '^Cc: *sta...@dpdk.org' ||
                git log --format='\t%s' -1 $fix
 done)
-[ -z "$bad" ] || printf "Should CC: sta...@dpdk.org\n$bad\n"
+[ -z "$bad" ] || printf "Should Cc: sta...@dpdk.org\n$bad\n"
+
+# check blank line after Cc: sta...@dpdk.org
+bad=$(echo "$bodylines" |
+       sed -n 'N;/\n$/D;/^C[Cc]: sta...@dpdk.org/P' |
+       sed 's,^.,\t&,')
+[ -z "$bad" ] || printf "Missing blank line after 'Cc: stable@':\n$bad\n"
@@ -170,9 +170,9 @@ bad=$(echo "$tags" |
 [ -z "$bad" ] || printf "Wrong tag:\n$bad\n"
 
-# check blank line after last Fixes: tag
+# check blank line (or Cc: stable) after last Fixes: tag
 bad=$(echo "$bodylines" |
-- 
2.7.0

Reply via email to